ContainsIncidence

Trait ContainsIncidence 

pub trait ContainsIncidence: IncidenceBase {
    // Required method
    fn contains_incidence(&self, incidence: Self::IncidenceId) -> bool;
}
Incidence-ID containment capability for an incidence-capable topology view.

This capability answers whether an incidence ID is valid and visible in this view at the time of the call.

Performance

Expected O(1) unless the implementation documents otherwise.

Required Methods

fn contains_incidence(&self, incidence: Self::IncidenceId) -> bool

Returns whether incidence is valid and visible in this view.

Performance

Expected O(1) unless the implementation documents otherwise.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors