DirectedHyperedgeIncidences

Trait DirectedHyperedgeIncidences 

pub trait DirectedHyperedgeIncidences: IncidenceBase {
    type SourceIncidences<'view>: Iterator<Item = Self::IncidenceId>
       where Self: 'view;
    type TargetIncidences<'view>: Iterator<Item = Self::IncidenceId>
       where Self: 'view;

    // Required methods
    fn source_incidences(
        &self,
        hyperedge: Self::RelationId,
    ) -> Self::SourceIncidences<'_>;
    fn target_incidences(
        &self,
        hyperedge: Self::RelationId,
    ) -> Self::TargetIncidences<'_>;
}
Capability for traversing directed participant incidence IDs.

Incidence-ID counterpart to DirectedHyperedgeParticipants. Algorithms that need incidence weights bind on this trait so they can choose target participants by incidence ID without adding weighted expansion traits to topology.

Required Associated Types

type SourceIncidences<'view>: Iterator<Item = Self::IncidenceId> where Self: 'view

Iterator over source-side participant incidence IDs.

type TargetIncidences<'view>: Iterator<Item = Self::IncidenceId> where Self: 'view

Iterator over target-side participant incidence IDs.

Required Methods

fn source_incidences( &self, hyperedge: Self::RelationId, ) -> Self::SourceIncidences<'_>

Returns source-side participant incidence IDs for hyperedge.

fn target_incidences( &self, hyperedge: Self::RelationId, ) -> Self::TargetIncidences<'_>

Returns target-side participant incidence IDs for hyperedge.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors