DirectedVertexPredecessors

Trait DirectedVertexPredecessors 

pub trait DirectedVertexPredecessors: ElementPredecessors {
    type VertexPredecessors<'view>: Iterator<Item = VertexId<Self>>
       where Self: 'view;

    // Required method
    fn predecessor_vertices(
        &self,
        vertex: VertexId<Self>,
    ) -> Self::VertexPredecessors<'_>;
}
Capability for expanding a directed hypergraph vertex to predecessor vertices.

Hypergraph-facing name for ElementPredecessors. A predecessor vertex is a source-side participant reachable through a directed hyperedge where the input vertex participates on the target side. The associated iterator GAT is named VertexPredecessors to avoid colliding with the inherited ElementPredecessors::Predecessors GAT.

Required Associated Types

type VertexPredecessors<'view>: Iterator<Item = VertexId<Self>> where Self: 'view

Iterator over predecessor vertices reaching one target-side vertex.

Required Methods

fn predecessor_vertices( &self, vertex: VertexId<Self>, ) -> Self::VertexPredecessors<'_>

Returns source-side vertices that can reach vertex.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors