pub trait DirectedVertexSuccessors: ElementSuccessors {
type VertexSuccessors<'view>: Iterator<Item = VertexId<Self>>
where Self: 'view;
// Required method
fn successor_vertices(
&self,
vertex: VertexId<Self>,
) -> Self::VertexSuccessors<'_>;
}Expand description
Capability for expanding a directed hypergraph vertex to successor vertices.
Hypergraph-facing name for ElementSuccessors. A successor vertex is a
target-side participant reachable through a directed hyperedge where the
input vertex participates on the source side. The associated iterator GAT
is named VertexSuccessors to avoid colliding with the inherited
ElementSuccessors::Successors GAT.
Required Associated Types
Sourcetype VertexSuccessors<'view>: Iterator<Item = VertexId<Self>>
where
Self: 'view
type VertexSuccessors<'view>: Iterator<Item = VertexId<Self>> where Self: 'view
Iterator over successor vertices reachable from one source-side vertex.
Required Methods
Sourcefn successor_vertices(
&self,
vertex: VertexId<Self>,
) -> Self::VertexSuccessors<'_>
fn successor_vertices( &self, vertex: VertexId<Self>, ) -> Self::VertexSuccessors<'_>
Returns target-side vertices reachable from vertex.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".