pub trait HyperedgeIndex: RelationIndex {
// Provided methods
fn hyperedge_bound(&self) -> usize { ... }
fn hyperedge_index(&self, hyperedge: Self::RelationId) -> usize { ... }
}Expand description
Dense hyperedge-index capability for hypergraph views.
Hypergraph-facing name for RelationIndex.
Provided Methods
Sourcefn hyperedge_bound(&self) -> usize
fn hyperedge_bound(&self) -> usize
Returns the exclusive upper bound for hyperedge indexes in this view.
Sourcefn hyperedge_index(&self, hyperedge: Self::RelationId) -> usize
fn hyperedge_index(&self, hyperedge: Self::RelationId) -> usize
Returns the dense index for hyperedge in this view.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".