pub trait LocalIncidenceIdentity: CanonicalIncidenceIdentity {
// Required method
fn local_incidence_id(
&self,
canonical: Self::CanonicalIncidenceId,
) -> Option<Self::IncidenceId>;
}Expand description
Optional canonical-to-local incidence identity capability.
This reverse lookup is separate from CanonicalIncidenceIdentity because
it may require extra memory or may be partial for filtered and projected
views.
Performance
Lookup should be O(1) unless an implementation documents a weaker
contract.
Required Methods
Sourcefn local_incidence_id(
&self,
canonical: Self::CanonicalIncidenceId,
) -> Option<Self::IncidenceId>
fn local_incidence_id( &self, canonical: Self::CanonicalIncidenceId, ) -> Option<Self::IncidenceId>
Returns the visible local incidence for canonical, if present.
Performance
Expected O(1) unless the implementation documents otherwise.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".