ParticipantIndex

Trait ParticipantIndex 

pub trait ParticipantIndex: IncidenceIndex {
    // Provided methods
    fn participant_bound(&self) -> usize { ... }
    fn participant_index(&self, participant: Self::IncidenceId) -> usize { ... }
}
Dense participant-index capability for hypergraph views with incidences.

Hypergraph-facing name for IncidenceIndex.

Provided Methods

fn participant_bound(&self) -> usize

Returns the exclusive upper bound for participant indexes in this view.

fn participant_index(&self, participant: Self::IncidenceId) -> usize

Returns the dense index for participant in this view.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors