HypergraphCounts

Trait HypergraphCounts 

pub trait HypergraphCounts: TopologyCounts {
    // Provided methods
    fn vertex_count(&self) -> usize { ... }
    fn hyperedge_count(&self) -> usize { ... }
}
Count capability for a hypergraph view.

Hypergraph-facing name for TopologyCounts.

Provided Methods

fn vertex_count(&self) -> usize

Returns the number of vertices visible in this hypergraph view.

fn hyperedge_count(&self) -> usize

Returns the number of hyperedges visible in this hypergraph view.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors